pub struct CachePaths {
pub metadata: PathBuf,
pub analysis: PathBuf,
}Expand description
The two files for one canonical root key in an application cache directory.
Fields
metadata: PathBufFilesystem entries and metadata.
analysis: PathBufDerived analyzer results.
Implementations
Sourceimpl CachePaths
impl CachePaths
Sourcepub fn for_root_hash(directory: &Path, root_hash: u64) -> Self
pub fn for_root_hash(directory: &Path, root_hash: u64) -> Self
Construct the conventional sibling paths for a canonical root hash.
Sourcepub fn from_metadata(metadata: &Path) -> Self
pub fn from_metadata(metadata: &Path) -> Self
Derive the sibling of an explicit metadata path.