pub fn classify_path(path: &Path) -> ClassificationExpand description
Classify from path metadata only, against the compiled default rules.
pub fn classify_path(path: &Path) -> ClassificationClassify from path metadata only, against the compiled default rules.