pub fn classify_path_with_prefix(
path: &Path,
prefix: Option<&[u8]>,
) -> ClassificationExpand description
Classify with an optional bounded content prefix, against the compiled default rules.
pub fn classify_path_with_prefix(
path: &Path,
prefix: Option<&[u8]>,
) -> ClassificationClassify with an optional bounded content prefix, against the compiled default rules.