pub struct IgnoredSize {
pub bytes: u64,
pub allocated: u64,
}Expand description
Exact ignored byte sizes on a disjoint omitted subtree. Directory inode usage is not part of either size metric.
Fields
bytes: u64Apparent bytes of ignored regular files.
allocated: u64Allocated bytes of ignored regular files.