pub struct SummaryRow {
pub files: u64,
pub dirs: u64,
pub bytes: u64,
pub allocated: u64,
pub ignored: Option<IgnoredTally>,
pub newest_mtime_ns: Option<i64>,
}Expand description
The aggregate row of a summary view.
Fields
files: u64Files selected.
dirs: u64Directories selected.
bytes: u64Apparent bytes.
allocated: u64Allocated bytes.
ignored: Option<IgnoredTally>The ignored part of what was selected, or None when governing rules were
unobserved or could not be verified for a contributing entry.
newest_mtime_ns: Option<i64>Newest modification time, when anything was selected.