load_serving

Function load_serving 

pub fn load_serving(
    path: &Path,
    types: Arc<TypeRegistry>,
    wanted: SnapshotIdentity,
) -> Result<LoadOutcome>
Load a snapshot that can serve wanted, projecting observed control state away when the entry tier is equal and the request does not observe controls.