pub enum ControlRefusalReason {
Budget,
LineLimit,
}Expand description
Which of the ControlLimits refused a control source instead of applying its rules.
Variants
Budget
Retaining the source would have taken the table past ControlLimits::budget.
LineLimit
A line of the source is longer than ControlLimits::line_limit.
Implementations