pub fn write(
report: &Report,
format: Format,
color: bool,
out: &mut dyn Write,
) -> Result<()>Expand description
Write a report directly to an output stream.
Machine formats retain only serializer depth while walking the report. Text remains a presentation renderer and is written after it is formatted.